@@ -2,6 +2,7 @@ import json
 
 
 class ReferencesSerializer:
+
     def serialize_details(self, references, format, prefix=None):
         resp = references
         if format == "text":
@@ -9,7 +10,8 @@ class ReferencesSerializer:
         references = references.json()
         if prefix:
             references = [
-                reference for reference in references if reference.startswith(prefix)
+                reference for reference in references
+                if reference.startswith(prefix)
             ]
         if format == "dict":
             return references
