@@ -1,22 +1,21 @@
 import json
 
-from apigee.utils import remove_last_items_from_list, run_func_on_iterable
+from apigee.utils import apply_function_on_iterable, remove_last_elements
 
 
 class SharedflowsSerializer:
+
     @staticmethod
     def filter_deployed_revisions(details):
         return list(
             set(
-                run_func_on_iterable(
-                    details, lambda d: d["revision"], state_op="extend"
-                )
-            )
-        )
+                apply_function_on_iterable(details,
+                                           lambda d: d["revision"],
+                                           state_op="extend")))
 
     @staticmethod
     def filter_deployment_details(details):
-        return run_func_on_iterable(
+        return apply_function_on_iterable(
             details["environment"],
             lambda d: {
                 "name": d["name"],
@@ -27,7 +26,7 @@ class SharedflowsSerializer:
     @staticmethod
     def filter_undeployed_revisions(revisions, deployed, save_last=0):
         undeployed = [int(rev) for rev in revisions if rev not in deployed]
-        return remove_last_items_from_list(sorted(undeployed), save_last)
+        return remove_last_elements(sorted(undeployed), save_last)
 
     @staticmethod
     def serialize_details(sharedflows, format, prefix=None):
@@ -37,8 +36,7 @@ class SharedflowsSerializer:
         sharedflows = sharedflows.json()
         if prefix:
             sharedflows = [
-                sharedflow
-                for sharedflow in sharedflows
+                sharedflow for sharedflow in sharedflows
                 if sharedflow.startswith(prefix)
             ]
         return json.dumps(sharedflows) if format == "json" else resp
