@@ -1,4 +1,4 @@
-APIS = {
+APIGEE_API_CHOICES = {
     "apis",
     "keyvaluemaps",
     "targetservers",
@@ -11,6 +11,7 @@ APIS = {
 
 
 class Struct:
+
     def __init__(self, **entries):
         self.__dict__.update(entries)
 
